AudioDataFormat

Enum AudioDataFormat 

#[non_exhaustive]
pub enum AudioDataFormat { U8 = 0, S16 = 1, S32 = 2, F32 = 3, U8Planar = 4, S16Planar = 5, S32Planar = 6, F32Planar = 7, }
The AudioSampleFormat enum.

This API requires the following crate features to be activated: AudioSampleFormat

This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as described in the wasm-bindgen guide

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


U8 = 0



S16 = 1



S32 = 2



F32 = 3



U8Planar = 4



S16Planar = 5



S32Planar = 6



F32Planar = 7

Implementations